// The following set of constants has been partly extracted from the NIST webpage:
//
// http://physics.nist.gov/constants
// 

format("v", 10);

// General
c 	= 3e8 			& _speed         & #USI;	// light speed in vacuum
Na 	= 6.02214179e23		& _mol^(-1)	 & #USI;	// Avogadro number
kB	= 1.3806504e-23		& (_J * _K^(-1)) & #USI;	// Boltzmann constant
h     	= 6.62608696e-34	& (_J * _s) 	 & #USI;	// Planck constant
hbar  	= h / (2 * %pi) 			 & #USI;	// reduced Planck constant
eps0  	= 8.854187817e-12 	& (_F * _m^(-1)) & #USI;	// electric constant
_4pi_eps0 = 4 * %pi * eps0;
mu0   	= (eps0 * c^2)^(-1);

// Electron
e       = 1.602176487e-19 	& _C ; 				// e- charge
gamma_e = 1.760859770e+11 	& (_s^(-1) * _T^(-1));		// e- gyromagnetic ratio
m_e     = 9.10938215e-31  	& _kg ;				// e- mass

// Proton
gamma_p = 2.675222099e+08  	& (_s^(-1) * _T^(-1));		// 1H gyromagnetic ratio
gamma_H = gamma_p ;						// idem (NMR notation)
m_p     = 1.672621637e-27  	& _kg ;				// 1H mass

// Neutron
gamma_n = 1.83247185e+08  	& (_s^(-1) * _T^(-1));		// neutron gyromagnetic ratio
m_n     = 1.674927211e-27  	& _kg ;				// neutron mass


// Deuteron
gamma_2H= 0.307012207 * gamma_p ;				// deuteron gyromagnetic ratio (derived from 1H's)
m_2H	= 2.3435832e-27   	& _kg ;				// deuteron mass


// Mechanics
G     	= 6.67428e-11 		& (_m^3 * _kg ^(-1) * _s^(-2)) 	& #USI ;  // Newtonian constant of gravitation
g	= 9.81			& (_m * _s^(-2) ) 		& #USI ;  // Earth gravity at its surface


// practical units:
_eV 	= 1 			& (e * _V)	& #USI; 	// electron-volt (energy)
_L 	= 1e-3			& (m ^(-3))	& #USI;		// litre (volume)