global('SystemList'); 
SystemList = list();
global('UnitStrings');
UnitStrings=list();
PRETTYPRINTEDUNIT = %T;

// Define a number of Units Sysems!
#USI       = defUnitSystem("#USI", [    1,    1,    1,    1,    1,    1,     1], ...
	     			   [  'm', 'kg',  's',  'A',  'K','mol',  'cd']);

#cgs       = defUnitSystem("#cgs", [1e-2, 1e-3,   1,   1,   1,     1,    1], ...
				   ['cm',  'g', 's', 'A', 'K', 'mol', 'cd'] );

////////////////////////////////////////////////////
// Define appropriate units and physical quantities:

// Elementary units & quantities:
_length       = defQuantity("#USI", 1, [1, 0, 0, 0, 0, 0, 0]);
_mass         = defQuantity("#USI", 1, [0, 1, 0, 0, 0, 0, 0]);
_time         = defQuantity("#USI", 1, [0, 0, 1, 0, 0, 0, 0]);
_current      = defQuantity("#USI", 1, [0, 0, 0, 1, 0, 0, 0]);
_temperature  = defQuantity("#USI", 1, [0, 0, 0, 0, 1, 0, 0]);
_matt_amount  = defQuantity("#USI", 1, [0, 0, 0, 0, 0, 1, 0]);
_light_intens = defQuantity("#USI", 1, [0, 0, 0, 0, 0, 0, 1]);

_1            = defQuantity("#USI", 1, [0, 0, 0, 0, 0, 0, 0]);  // for all non-dimensional quantities

_m       = 1 & _length       & #USI ;			// meter (Distance)
_kg      = 1 & _mass         & #USI ;			// kilogram (Mass)
_s       = 1 & _time         & #USI ;			// second (Time, Duration)
_A       = 1 & _current      & #USI ;			// ampere (Charge Current)
_K       = 1 & _temperature  & #USI ;			// Kelvin (Temperature)
_mol     = 1 & _matt_amount  & #USI ;			// mole (Quantity of Matter)
_cd      = 1 & _light_intens & #USI ;			// candela (Light Intensity)

_freq	   = defQuantity("#USI", 1, [0, 0, -1]);
_puls      = defQuantity("#USI", 2*%pi, [0, 0, -1]);
_impuls    = defQuantity("#USI", 1, [-1, 0, 0]);
_Hz	   = defQuantity("#USI", 1,  [0, 0, -1]);	// hertz (frequency, pulsation)

_surf    = defQuantity("#USI", 1, [2, 0, 0]);
_volume  = defQuantity("#USI", 1, [2, 0, 0]);

_rad     = defQuantity("#USI", 1, [0, 0, 0]);		// radian (Angle)
_sr      = defQuantity("#USI", 1, [0, 0, 0]);		// steradian (Solid Angle)


// General & Mechanics:
_speed     = defQuantity("#USI", 1, [1, 0, -1]);
_accel     = defQuantity("#USI", 1, [1, 0, -2]);
_energy    = defQuantity("#USI", 1, [2, 1, -2]);
_momentum  = defQuantity("#USI", 1, [2, 1, -1]);
_force     = defQuantity("#USI", 1, [1, 1, -2]);
_power     = defQuantity("#USI", 1, [2, 1, -3]);
_pressure  = defQuantity("#USI", 1, [-1, 1, -2]);

_degC = 1 &  _K                  & #USI ;		// degree Celsius (Beware of K<->C conversions !!)
_N    = 1 & _force               & #USI ;		// newton (Force)
_Pa   = 1 & _pressure            & #USI ;		// pascal (Pressure, Stress)
_J    = 1 & _energy              & #USI ;		// joule (Energy, Work, Quantity of Heat)
_W    = 1 & (_J * _s^(-1))       & #USI ;		// watt (Power, Radiant Flux)

// Electro-magnetism:
_C    = 1 & (_s * _A)           & #USI ;		// coulomb (Electric charge)
_V    = 1 & (_W / _A)           & #USI ;		// volt (Electric Potential Difference, Electromotive Force)
_Ohm  = 1 & (_V / _A)           & #USI ;		// ohm (Electric Resistance)
_T    = 1 & (_V * _s * _m^(-2)) & #USI ;		// tesla (Magnetic Flux Density)
_F    = 1 & (_C / _V )          & #USI ;		// farad (Capacitance)
_S    = 1 & (_A / _V )          & #USI ;		// siemens (Electric Conductance)
_Wb   = 1 & (_V * _s )          & #USI ;		// weber (Magnetic Flux)
_H    = 1 & (_Wb / _A)          & #USI ;		// henry (Inductance)
_lm   = 1 & (_cd * _sr)         & #USI ;		// lumen (Luminous Flux)
_lx   = 1 & (_lm * _m^(-2))     & #USI ;		// lux (Illuminance)
_Bq   = 1 & (_s^(-1))           & #USI ;		// becquerel (Radionucleide Activity)
_Gy   = 1 & (_J * _kg^(-1))     & #USI ;		// gray (Absorbed Dose, Specific Energy (Imparted), Kerma)
_Sv   = 1 & (_J * _kg^(-1))     & #USI ;		// sievert (Dose Equivalent)
_kat  = 1 & (_mol * _s^(-1))    & #USI ;		// katal (Catalytic Activity)

// Define related strings for unit display:
defVisualUnit(_speed	 	, "(speed)"			);
defVisualUnit(_accel	 	, "(accel.)"			);
defVisualUnit(_energy		, "(energy)"			);
defVisualUnit(_momentum		, "(kinetic momentum)"		);
defVisualUnit(_momentum *_s	, "(inertial momentum)"		);
defVisualUnit(_force		, "(force)"			);
defVisualUnit(_power		, "(power)"			);
defVisualUnit(_pressure		, "(pressure)"			);
defVisualUnit(_impuls		, "(wavenumber)"		);
defVisualUnit(_C		, "(elec. charge)"		);
defVisualUnit(_V / _m		, "(elec. field strength)"	);
defVisualUnit(_V		, "(elec. potential)"		);
defVisualUnit(_Ohm		, "(elec. resistance)"		);
defVisualUnit(_T		, "(magn. flux density)"	);
defVisualUnit(_F		, "(elec. capacitance)"		);
defVisualUnit(_S		, "(elec. conductance)"		);
defVisualUnit(_Wb		, "(magn. flux)"		);
defVisualUnit(_A / _m		, "(magn. field strength)"	);
defVisualUnit(_H		, "(inductance)"		);
defVisualUnit(_lm		, "(light flux)"		);
defVisualUnit(_Gy		, "(abs. dose / spec. energy)"	);
defVisualUnit(_kat		, "(catal. activity)"		);
